#Exercise_1 Script 5 - Examples of Regression using Meta Data
#Execute Load Observed Data.R before running this script
require(lme4)
require(lmerTest)


#############Linear mixed effect model with PubID as Random ########################
#data weighted using the N of obs per treatment
sqrt(o$N_study)

#RUP flow predictions based on a single DC
lmod <- lmer(Obs_RUPIn ~ Dt_CPIn + (1|PubID), data=o, weights = sqrt(N_study), REML=FALSE)
lmod <- lmer(Obs_RUPIn ~ Dt_CPIn + (1|PubID), data=o, weights = sqrt(N_study), REML=TRUE) #Stats are very similar for REML vs LLF

summary(lmod)

o$Pr_RUPIn_lin <- predict(lmod, re.form=NA)     #predict w/out study effects (re.form=NA) writing back to df
RMSE(o$Obs_RUPIn, o$Pr_RUPIn_lin)


############## Nonlinear LMER Model with PubID as Random ###########################
parms1 <- c("Int","KpA","KpB","KpC")
inputs1 <- c("Dt_CPAIn","Dt_CPBIn","Dt_CPCIn","KdRUP")  #Kd are derived from in situ analyses of the ingredients
args1 <- append(inputs1, parms1)

init1 <- c(Int = 0.0, KpA = 0.2, KpB = 2.0, KpC=1.0)
#lowerbound <- c(KpC=0, Int=-.2, KpFor=0.0, KpConc=0)
#upperbound <- c(KpC=1.0, Int=0.7, KpFor=10, KpConc=12)

#formnlmer is the model to predict the observed values. Documentation indicates the Int is required.
formnlmer <- ~ Int + Dt_CPAIn * KpA + Dt_CPBIn * KpB/(KdRUP + KpB) + Dt_CPCIn * KpC
form.d <- deriv(formnlmer, parms1, function.arg = args1)    #the derivative of formnlmer
nlmod1 <- nlmer(Obs_RUPIn ~ form.d(Dt_CPAIn, Dt_CPBIn, Dt_CPCIn, KdRUP,Int, KpA, KpB, KpC) ~ (Int|PubID), 
              data = o, #weights = sqrt(N_study),
              start = init1, 
              verbose=1,
              nlmerControl(optimizer = "Nelder_Mead"))
#Allows data weighting as for lmer, but wont' converge with weights = sqrt(N_study)
summary(nlmod1)

#Calculate RMSE and CCC for each prediction to determine goodness of fit
obs <- o$Obs_RUPIn

predl <- predict(lmod, re.form=NA)     #predict w/out study effects (re.form=NA)
predlran <- predict(lmod)     #predict w study effects
prednl1 <- predict(nlmod1)    #re.form option does not work for nlin models

#load and execute the RMSE_CCC Funciton script to make the RMSE fuction available
RMSE(obs,predl)
RMSE(obs,predlran)
RMSE(obs,prednl1)

plot(obs,prednl1)

#use the resprgrplt function from Plot Residuals Functions.R
resprgrpplt(obs,predl,o$PubID,"RUP (linear DC)")
resprgrpplt(obs,predlran,o$PubID,"RUP (linear DC)")
resprgrpplt(obs,prednl1,o$PubID,"RUP (Kd/Kp)")

#Predict RDP intake by difference
o$Pr_RDPIn <- o$Dt_CPIn - o$Pr_RUPIn_lin

#Predict Micr CP flow from RDP intake
o$Du_MiCP <- o$Du_MiN_g/1000 * 6.25
lm_micrCP <- lmer(Du_MiCP ~ Pr_RDPIn + Dt_NDF + Dt_St + (1|PubID), 
                  data=o, weights = sqrt(N_study), REML=FALSE)
summary(lm_micrCP)
o$Pr_MiCP <- predict(lm_micrCP, re.form=NA)

#Predict CP digested in the intestine
o$Fe_CP <- o$Fe_N * 6.25
o$Dg_CP_SI <- o$Pr_MiCP + o$Pr_RUPIn_lin - o$Fe_CP

lm_DgCP <- lmer(Dg_CP_SI ~ Pr_RUPIn_lin + Pr_MiCP + (1|PubID), 
                  data=o, weights = sqrt(N_study), REML=FALSE)
summary(lm_DgCP)  #too much correlation to estimate

o$Pr_DuCP <- o$Pr_MiCP + o$Pr_RUPIn_lin
lm_DgCP <- lmer(Dg_CP_SI ~ Pr_DuCP + (1|PubID), 
                data=o, weights = sqrt(N_study), REML=FALSE)
summary(lm_DgCP)
o$Pr_DgCP_SI <- predict(lm_DgCP, re.form=NA)


#Predict Milk Protein Production from predicted digested CP
o$Obs_MilkTP <- o$Obs_MilkTP_g / 1000

lm_MlTP <- lmer(Obs_MilkTP ~ An_DEIn + Pr_DgCP_SI + I(Pr_DgCP_SI^2) + (1|PubID), 
                data=o, weights = sqrt(N_study), REML=FALSE)
summary(lm_MlTP)

Pr_MlTP <- predict(lm_MlTP, re.form=NA)  #Can't write directly to the df with missing values
Ob <- subset(o, !is.na(o$Obs_MilkTP), select=c("PubID","TID","Obs_MilkTP"))

RMSE(Ob$Obs_MilkTP,Pr_MlTP)
resprgrpplt(Ob$Obs_MilkTP,Pr_MlTP,Ob$PubID,"Milk TP, kg/d")
